/*!
 * @file        main.c
 *
 * @brief       Main program body        
 *
 * @version     V1.0.0
 *
 * @date        2019-11-4
 *
 */

#include "main.h"
#include "Board.h"
#include "apm32f00x_gpio.h"
#include "apm32f00x_rcm.h"

/* System tick */
uint32_t sysTick = 0;

/* Led Init */
void LedInit(void);


/*!
 * @brief       Main program
 *
 * @param       None
 *
 * @retval      None
 *
 * @note       
 */
int main(void)
{
    /* Setup SysTick Timer for 1 msec interrupts */
    SysTick_Config(RCM_GetMasterClockFreq() / 1000);
    
    LedInit();
    
    while(1)
    {
        if(sysTick >= 500)
        {
            sysTick = 0;
            
            Board_LedToggle(BOARD_LED2);
            Board_LedToggle(BOARD_LED3);
        }
    }
}

/*!
 * @brief       Led init   
 *
 * @param       None
 *
 * @retval      None
 *
 * @note
 */
void LedInit(void)
{
    Board_LedInit(BOARD_LED2);
    Board_LedInit(BOARD_LED3);
    
    Board_LedOff(BOARD_LED2);
    Board_LedOn(BOARD_LED3);  
}

